#!/bin/sh
logger -t lvm-setup -- Start User: "$USER" Home: "$HOME:" ID: "$(id)"
eval $(get-netinfo --shell)
logger -t get-netinfo group $NETGROUP, interface $NETIFACE, ip $INETADDR

export http_proxy no_proxy ftp_proxy

rm -f .daily.pem
openssl pkcs12 -info -nodes -in ~/.daily.p12 -passin pass:"" > .daily.pem
chmod 600 .daily.pem

# Userinfo
getuserinfo=false
database="ltlvm40/admin/id_names_rel85.nsf"

if [ "${NETSTAT}" = stat ]; then
    getuserinfo=true
fi
if [ "${NETSTAT}" = mobi -a ! -f "$HOME/.userinfo" ]; then
    getuserinfo=true
fi
if $getuserinfo; then
    logger -t lvm-setup -- getting user info
    rm -f "$HOME/.userinfo.new" "$HOME/.userinfo2.new"
    ( 
	# unset http_proxy;
	curl --proxy "" --fail --silent --retry 0 --connect-timeout 20 --max-time 30 --capath /etc/pam_pkcs11/cacerts/ -E .daily.pem  --output "$HOME/.userinfo.new" "http://las.lvm.de/intra/bm2/get-userinfo.jsp?userid=$USER"
	curl --proxy "" --fail --silent --retry 0 --connect-timeout 20 --max-time 30 --capath /etc/pam_pkcs11/cacerts/ -E .daily.pem --output  "$HOME/.userinfo2.new" "https://inotes.lvm.de/$database/notesclientuser.txt" 
	test -s "$HOME/.userinfo.new" && grep -s "Generated by" "$HOME/.userinfo.new" >/dev/null 2>&1 && mv "$HOME/.userinfo.new" "$HOME/.userinfo"
	cat "$HOME/.userinfo2.new" >> "$HOME/.userinfo"
	rm -f "$HOME/.userinfo2.new"
	) &
fi

# Add MS TT Corefonts to X11 fontpath - just to be safe
if ! xset q | grep -q msttcorefonts; then 
    xset fp+ /usr/share/fonts/msttcorefonts/
fi

# Acrobat Reader
acrodir="$HOME/.adobe/Acrobat/7.0/Preferences"
if [ ! -d "$acrodir" ]; then
    mkdir -p "$acrodir"
    sed -e "s/@@USERID@@/$USER/" /etc/default/AdobeReaderPrefs >"$acrodir/reader_prefs"
    logger -t lvm-common-presession -- created default Adobe Reader preferences in "$acrodir/reader_prefs"
fi

# if [ ! -f "$HOME/.realplayerrc" ]; then
#    sed -e "s/@@USERID@@/$USER/" /etc/default/RealPlayerRC >"$HOME/.realplayerrc"
#    logger -t lvm-common-presession -- created default RealPlayer preferences in "$HOME/.realplayerrc"
# fi

if [ ! -d "$HOME/.gnome2" ]; then
    logger -t lvm-setup -- created .gnome2 in home dir
    mkdir "$HOME/.gnome2"
fi
if [ ! -d "$HOME/.logs" ]; then
    logger -t lvm-setup -- created .logs in home dir
    mkdir "$HOME/.logs"
fi
if [ ! -d "$HOME/Pictures" ]; then
    logger -t lvm-setup -- created Pictures in home dir
    mkdir "$HOME/Pictures"
fi

# cp /etc/default/session-manual "$HOME/.gnome2/session-manual"
# [ -f "$HOME/.gnome2/session" ] && rm -f "$HOME/.gnome2/session"

if [ -f "$HOME/.lpoptions" ]; then
    logger -t lvm-setup -- purges .lpoptions in home dir
    rm -f "$HOME/.lpoptions"
fi

if [ -f "$HOME/.kde/Autostart/preload.sh" ]; then
    rm -f "$HOME/.kde/Autostart/preload.sh"
    rmdir "$HOME/.kde/Autostart"
    rmdir "$HOME/.kde"
fi

if [ -f "$HOME/.config/autostart/ped-gnome-screensaver.desktop" ]; then
    rm -f "$HOME/.config/autostart/ped-gnome-screensaver.desktop"
fi

if [ ! -d "$HOME/.mozilla/firefox" ]; then
    logger -t lvm-setup -- setup firefox default profile begin
    firefox -CreateProfile default
    logger -t lvm-setup -- setup firefox default profile done
fi

if [ ! -d "$HOME/.openoffice.org2.0" -a -x /usr/bin/ooffice ]; then
    logger -t lvm-setup -- setup openoffice profile begin
    /usr/bin/ooffice -terminate_after_init
    logger -t lvm-setup -- setup openoffice profile done
fi
logger -t lvm-setup -- check smartcard in 60 seconds
( sleep 60; scinfo ) &

logger -t lvm-setup -- update user desktop
update-user-desktop -v

logger -t lvm-setup -- update browser profile
update-browser-profile -v

logger -t lvm-setup -- update netinfo
update-netinfo

if [ -d "$HOME/.mozilla/eclipse" ]; then
    cp "$HOME/.mozilla/firefox"/*.default/*.db "$HOME/.mozilla/firefox"/*.default/*.js "$HOME/.mozilla/firefox"/*.default/*.txt "$HOME/.mozilla/eclipse/"
    logger -t lvm-setup -- copied firefox config to notes internal webbrowser config
fi

logger -t lvm-setup -- done
